@@ -25,6 +25,9 @@ sub new {
 
 =head2 add
 Adds an error.
+parameters:
+- message
+- path
 =cut
 sub add {
     my $self = shift;
@@ -33,6 +36,28 @@ sub add {
     push @{$self->{errors}}, $error;
 }
 
+=head2 add_error
+Adds an error object
+=cut
+sub add_error {
+    my $self = shift;
+    my $e    = shift;
+    push @{$self->{errors}}, $e;
+}
+
+=head2 add_collection
+Adds another error collection
+=cut
+sub add_collection{
+    my $self  = shift;
+    my $other = shift;
+    my @e = $other->as_array();
+    for (@e){
+        $self->add_error($_);
+    }
+
+}
+
 =head2 any_error_contains
 Return true if any of the collected errors contains a given string.
   $error->collection->any_error_contains(
